==> worker_2.8.4.orig.tar.gz: worker-2.8.4/src/configtokens.cc <==
/* configtokens.cc
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2003 Ralf Hoffmann.
 * You can contact me at: ralf.hoffmann@epost.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: configtokens.cc,v 1.10 2004/03/07 22:29:30 ralf Exp $ */

#include "wdefines.h"
#include <aguix/util.h>
#include "configtokens.h"
#include "configparser.tab.h"

struct mytoken tokenlist[]={
  {GLOBAL_WCP,"global"},
  {COLORS_WCP,"colors"},
  {LANG_WCP,"lang"},
  {PALETTE_WCP,"palette"},
  {OWNOP_WCP,"ownop"},
  {LISTERSETS_WCP,"listersets"},
  {LEFT_WCP,"left"},
  {RIGHT_WCP,"right"},
  {HBARTOP_WCP,"hbartop"},
  {HBARHEIGHT_WCP,"hbarheight"},
  {VBARLEFT_WCP,"vbarleft"},
  {VBARWIDTH_WCP,"vbarwidth"},
  {DISPLAYSETS_WCP,"displaysets"},
  {NAME_WCP,"name"},
  {SIZE_WCP,"size"},
  {TYPE_WCP,"type"},
  {PERMISSION_WCP,"permission"},
  {OWNER_WCP,"owner"},
  {DESTINATION_WCP,"destination"},
  {MODTIME_WCP,"modtime"},
  {ACCTIME_WCP,"acctime"},
  {CHGTIME_WCP,"chgtime"},
  {ROWS_WCP,"rows"},
  {COLUMNS_WCP,"columns"},
  {CACHESIZE_WCP,"cachesize"},
  {OWNERSTYLE_WCP,"ownerstyle"},
  {TERMINAL_WCP,"terminal"},
  {USESTRINGFORDIRSIZE_WCP,"usestringfordirsize"},
  {TIMESETS_WCP,"timesets"},
  {STYLE1_WCP,"style1"},
  {STYLE2_WCP,"style2"},
  {STYLE3_WCP,"style3"},
  {DATE_WCP,"date"},
  {TIME_WCP,"time"},
  {DATESUBSTITUTION_WCP,"datesubstitution"},
  {DATEBEFORETIME_WCP,"datebeforetime"},
  {STATEBAR_WCP,"statebar"},
  {SELLVBAR_WCP,"sellvbar"},
  {UNSELLVBAR_WCP,"unsellvbar"},
  {CLOCKBAR_WCP,"clockbar"},
  {REQUESTER_WCP,"requester"},
  {UNSELDIR_WCP,"unseldir"},
  {SELDIR_WCP,"seldir"},
  {UNSELFILE_WCP,"unselfile"},
  {SELFILE_WCP,"selfile"},
  {UNSELACTDIR_WCP,"unselactdir"},
  {SELACTDIR_WCP,"selactdir"},
  {UNSELACTFILE_WCP,"unselactfile"},
  {SELACTFILE_WCP,"selactfile"},
  {LVBG_WCP,"lvbg"},
  {STARTUP_WCP,"startup"},
  {BUTTON_WCP,"button"},
  {BUTTONS_WCP,"buttons"},
  {POSITION_WCP,"position"},
  {TITLE_WCP,"title"},
  {COMMANDS_WCP,"commands"},
  {SHORTKEYS_WCP,"shortkeys"},
  {PATHS_WCP,"paths"},
  {PATH_WCP,"path"},
  {FILETYPES_WCP,"filetypes"},
  {FILETYPE_WCP,"filetype"},
  {NORMAL_WCP,"normal"},
  {NOTYETCHECKED_WCP,"notyetchecked"},
  {UNKNOWN_WCP,"unknown"},
  {NOSELECT_WCP,"noselect"},
  {DIR_WCP,"dir"},
  {USEPATTERN_WCP,"usepattern"},
  {USECONTENT_WCP,"usecontent"},
  {PATTERN_WCP,"pattern"},
  {CONTENT_WCP,"content"},
  {FTCOMMANDS_WCP,"ftcommands"},
  {DND_WCP,"dnd"},
  {DC_WCP,"doubleclick"},
  {SHOW_WCP,"show"},
  {RAWSHOW_WCP,"rawshow"},
  {USER_WCP,"user"},
  {FLAGS_WCP,"flags"},
  {IGNOREDIRS_WCP,"ignoredirs"},
  {HOTKEYS_WCP,"hotkeys"},
  {HOTKEY_WCP,"hotkey"},
  {FONTS_WCP,"fonts"},
  {GLOBALFONT_WCP,"globalfont"},
  {BUTTONFONT_WCP,"buttonfont"},
  {LEFTFONT_WCP,"leftfont"},
  {RIGHTFONT_WCP,"rightfont"},
  {CLOCKBARSETS_WCP,"clockbarsets"},
  {MODUS_WCP,"modus"},
  {TIMESPACE_WCP,"timespace"},
  {TIME_WCP,"time"},
  {VERSION_WCP,"version"},
  {EXTERN_WCP,"extern"},
  {UPDATETIME_WCP,"updatetime"},
  {PROGRAM_WCP,"program"},
  {KEY_WCP,"key"},
  {DOUBLE_WCP,"double"},
  {MOD_WCP,"mod"},
  {CONTROL_WCP,"control"},
  {SHIFT_WCP,"shift"},
  {LOCK_WCP,"lock"},
  {MOD1_WCP,"mod1"},
  {MOD2_WCP,"mod2"},
  {MOD3_WCP,"mod3"},
  {MOD4_WCP,"mod4"},
  {MOD5_WCP,"mod5"},
  {DNDACTION_WCP,"dndaction"},
  {DCACTION_WCP,"doubleclickaction"},
  {SHOWACTION_WCP,"showaction"},
  {RSHOWACTION_WCP,"rawshowaction"},
  {USERACTION_WCP,"useraction"},
  {ROWUP_WCP,"rowup"},
  {ROWDOWN_WCP,"rowdown"},
  {CHANGEHIDDENFLAG_WCP,"changehiddenflag"},
  {COPYOP_WCP,"copyop"},
  {FIRSTROW_WCP,"firstrow"},
  {LASTROW_WCP,"lastrow"},
  {PAGEUP_WCP,"pageup"},
  {PAGEDOWN_WCP,"pagedown"},
  {SELECTOP_WCP,"selectop"},
  {SELECTALLOP_WCP,"selectallop"},
  {SELECTNONEOP_WCP,"selectnoneop"},
  {INVERTALLOP_WCP,"invertallop"},
  {PARENTDIROP_WCP,"parentdirop"},
  {ENTERDIROP_WCP,"enterdirop"},
  {CHANGELISTERSETOP_WCP,"changelistersetop"},
  {SWITCHLISTEROP_WCP,"switchlisterop"},
  {FILTERSELECTOP_WCP,"filterselectop"},
  {FILTERUNSELECTOP_WCP,"filterunselectop"},
  {PATHTOOTHERSIDEOP_WCP,"path2osideop"},
  {QUITOP_WCP,"quitop"},
  {DELETEOP_WCP,"deleteop"},
  {RELOADOP_WCP,"reloadop"},
  {MAKEDIROP_WCP,"makedirop"},
  {RENAMEOP_WCP,"renameop"},
  {DIRSIZEOP_WCP,"dirsizeop"},
  {SIMDDOP_WCP,"simddop"},
  {STARTPROGOP_WCP,"startprogop"},
  {SEARCHENTRYOP_WCP,"searchentryop"},
  {ENTERPATHOP_WCP,"enterpathop"},
  {SCROLLLISTEROP_WCP,"scrolllisterop"},
  {CREATESYMLINKOP_WCP,"createsymlinkop"},
  {CHANGESYMLINKOP_WCP,"changesymlinkop"},
  {CHMODOP_WCP,"chmodop"},
  {TOGGLELISTERMODEOP_WCP,"togglelistermodeop"},
  {SETSORTMODEOP_WCP,"setsortmodeop"},
  {SETFILTEROP_WCP,"setfilterop"},
  {SHORTKEYFROMLISTOP_WCP,"shortkeyfromlistop"},
  {CHOWNOP_WCP,"chownop"},
  {WORKERCONFIG_WCP,"workerconfig"},
  {USERSTYLE_WCP,"userstyle"},
  {DATESTRING_WCP,"datestring"},
  {TIMESTRING_WCP,"timestring"},
  {COLOR_WCP,"color"},
  {PATTERNIGNORECASE_WCP,"patternignorecase"},
  {PATTERNUSEREGEXP_WCP,"patternuseregexp"},
  {PATTERNUSEFULLNAME_WCP,"patternusefullname"},
  {COM_WCP,"com"},
  {SEPARATEEACHENTRY_WCP,"separateeachentry"},
  {RECURSIVE_WCP,"recursive"},
  {START_WCP,"start"},
  {TERMINALWAIT_WCP,"terminalwait"},
  {SHOWOUTPUT_WCP,"showoutput"},
  {VIEWSTR_WCP,"viewstr"},
  {INBACKGROUND_WCP,"inbackground"},
  {TAKEDIRS_WCP,"takedirs"},
  {ACTIONNUMBER_WCP,"actionnumber"},
  {ROWUP_WCP,"rowup"},
  {HIDDENFILES_WCP,"hiddenfiles"},
  {HIDE_WCP,"hide"},
  {TOGGLE_WCP,"toggle"},
  {FOLLOWSYMLINKS_WCP,"followsymlinks"},
  {MOVE_WCP,"move"},
  {RENAME_WCP,"rename"},
  {SAMEDIR_WCP,"samedir"},
  {REQUESTDEST_WCP,"requestdest"},
  {REQUESTFLAGS_WCP,"requestflags"},
  {OVERWRITE_WCP,"overwrite"},
  {ALWAYS_WCP,"always"},
  {NEVER_WCP,"never"},
  {COPYMODE_WCP,"copymode"},
  {FAST_WCP,"fast"},
  {PRESERVEATTR_WCP,"preserveattr"},
  {MODE_WCP,"mode"},
  {ACTIVE_WCP,"active"},
  {ACTIVE2OTHER_WCP,"active2other"},
  {SPECIAL_WCP,"special"},
  {REQUEST_WCP,"request"},
  {CURRENT_WCP,"current"},
  {OTHER_WCP,"other"},
  {FILTER_WCP,"filter"},
  {QUICK_WCP,"quick"},
  {ALSOACTIVE_WCP,"alsoactive"},
  {RESETDIRSIZES_WCP,"resetdirsizes"},
  {KEEPFILETYPES_WCP,"keepfiletypes"},
  {RELATIVE_WCP,"relative"},
  {ONFILES_WCP,"onfiles"},
  {ONDIRS_WCP,"ondirs"},
  {SORTBY_WCP,"sortby"},
  {SORTFLAG_WCP,"sortflag"},
  {REVERSE_WCP,"reverse"},
  {DIRLAST_WCP,"dirlast"},
  {DIRMIXED_WCP,"dirmixed"},
  {EXCLUDE_WCP,"exclude"},
  {INCLUDE_WCP,"include"},
  {UNSET_WCP,"unset"},
  {UNSETALL_WCP,"unsetall"},
  {SCRIPTOP_WCP,"scriptop"},
  {NOP_WCP,"nop"},
  {PUSH_WCP,"push"},
  {LABEL_WCP,"label"},
  {IF_WCP,"if"},
  {END_WCP,"end"},
  {POP_WCP,"pop"},
  {SETTINGS_WCP,"settings"},
  {WINDOW_WCP,"window"},
  {GOTO_WCP,"goto"},
  {PUSHUSEOUTPUT_WCP,"pushuseoutput"},
  {DODEBUG_WCP,"dodebug"},
  {WPURECURSIVE_WCP,"wpurecursive"},
  {WPUTAKEDIRS_WCP,"wputakedirs"},
  {STACKNR_WCP,"stacknr"},
  {PUSHSTRING_WCP,"pushstring"},
  {IFTEST_WCP,"iftest"},
  {IFLABEL_WCP,"iflabel"},
  {WINTYPE_WCP,"wintype"},
  {OPEN_WCP,"open"},
  {CLOSE_WCP,"close"},
  {LEAVE_WCP,"leave"},
  {CHANGEPROGRESS_WCP,"changeprogress"},
  {CHANGETEXT_WCP,"changetext"},
  {PROGRESSUSEOUTPUT_WCP,"progressuseoutput"},
  {WINTEXTUSEOUTPUT_WCP,"wintextuseoutput"},
  {PROGRESS_WCP,"progress"},
  {WINTEXT_WCP,"wintext"},
  {SHOWDIRCACHEOP_WCP,"showdircacheop"},
  {ACTIVESIDE_WCP,"activeside"},
  {SHOWFREESPACE_WCP,"showfreespace"},
  {ACTIVEMODE_WCP,"activemode"},
  { INODE_WCP, "inode" },
  { NLINK_WCP, "nlink" },
  { BLOCKS_WCP, "blocks" },
  { SHOWHEADER_WCP, "showheader" },
  { LVHEADER_WCP, "lvheader" },
  { IGNORECASE_WCP, "ignorecase" },
  { LISTVIEWS_WCP, "listviews" },
  { BLL_WCP, "bll" },
  { LBL_WCP, "lbl" },
  { LLB_WCP, "llb" },
  { BL_WCP, "bl" },
  { LB_WCP, "lb" },
  { LAYOUT_WCP, "layout" },
  { BUTTONSVERT_WCP, "buttonsvertical" },
  { LISTVIEWSVERT_WCP, "listviewsvertical" }
};

ArrayList *tokenlist_sorted = NULL;

int tokenlist_sortfunction( void *p1, void *p2 )
{
  if ( ( p1 == NULL ) || ( p2 == NULL ) ) return 0;
  return strcasecmp( ((struct mytoken*)p1)->str,
                     ((struct mytoken*)p2)->str );
}

void cleanUpTokens()
{
  // the list contains just pointers to the static array so
  // delete of list is enough
  delete tokenlist_sorted;
  tokenlist_sorted = NULL;
}

int findToken( const char *str)
{
  int s, i, left, right, middle, erg;
  struct mytoken *t1;
  
  if ( tokenlist_sorted == NULL ) {
    // init sorted token list for binary search
    tokenlist_sorted = new ArrayList();
    s = sizeof( tokenlist ) / sizeof( tokenlist[0] );
    for ( i = 0; i < s; i++ ) {
      tokenlist_sorted->addElement( &( tokenlist[i] ) );
    }
    tokenlist_sorted->sort( tokenlist_sortfunction );
  }
  
  s = tokenlist_sorted->size();
  left = 0;
  right = s - 1;
  do {
    middle = ( left + right ) / 2;
    t1 = (struct mytoken*)tokenlist_sorted->getElementAt( middle );
    if ( t1 == NULL ) return ERROR;
    erg = strcasecmp( str, t1->str );
    if ( erg == 0 ) return t1->token;
    else if ( erg < 0 ) {
      right = middle - 1;
    } else {
      left = middle + 1;
    }
  } while ( left <= right );
  return ERROR;
}

==> worker_2.8.5.orig.tar.gz: worker-2.8.5/src/configtokens.cc <==
/* configtokens.cc
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2003-2004 Ralf Hoffmann.
 * You can contact me at: ralf.hoffmann@epost.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: configtokens.cc,v 1.12 2004/06/13 21:21:28 ralf Exp $ */

#include "wdefines.h"
#include <aguix/util.h>
#include "configtokens.h"
#include "configparser.tab.h"

struct mytoken tokenlist[]={
  {GLOBAL_WCP,"global"},
  {COLORS_WCP,"colors"},
  {LANG_WCP,"lang"},
  {PALETTE_WCP,"palette"},
  {OWNOP_WCP,"ownop"},
  {LISTERSETS_WCP,"listersets"},
  {LEFT_WCP,"left"},
  {RIGHT_WCP,"right"},
  {HBARTOP_WCP,"hbartop"},
  {HBARHEIGHT_WCP,"hbarheight"},
  {VBARLEFT_WCP,"vbarleft"},
  {VBARWIDTH_WCP,"vbarwidth"},
  {DISPLAYSETS_WCP,"displaysets"},
  {NAME_WCP,"name"},
  {SIZE_WCP,"size"},
  {TYPE_WCP,"type"},
  {PERMISSION_WCP,"permission"},
  {OWNER_WCP,"owner"},
  {DESTINATION_WCP,"destination"},
  {MODTIME_WCP,"modtime"},
  {ACCTIME_WCP,"acctime"},
  {CHGTIME_WCP,"chgtime"},
  {ROWS_WCP,"rows"},
  {COLUMNS_WCP,"columns"},
  {CACHESIZE_WCP,"cachesize"},
  {OWNERSTYLE_WCP,"ownerstyle"},
  {TERMINAL_WCP,"terminal"},
  {USESTRINGFORDIRSIZE_WCP,"usestringfordirsize"},
  {TIMESETS_WCP,"timesets"},
  {STYLE1_WCP,"style1"},
  {STYLE2_WCP,"style2"},
  {STYLE3_WCP,"style3"},
  {DATE_WCP,"date"},
  {TIME_WCP,"time"},
  {DATESUBSTITUTION_WCP,"datesubstitution"},
  {DATEBEFORETIME_WCP,"datebeforetime"},
  {STATEBAR_WCP,"statebar"},
  {SELLVBAR_WCP,"sellvbar"},
  {UNSELLVBAR_WCP,"unsellvbar"},
  {CLOCKBAR_WCP,"clockbar"},
  {REQUESTER_WCP,"requester"},
  {UNSELDIR_WCP,"unseldir"},
  {SELDIR_WCP,"seldir"},
  {UNSELFILE_WCP,"unselfile"},
  {SELFILE_WCP,"selfile"},
  {UNSELACTDIR_WCP,"unselactdir"},
  {SELACTDIR_WCP,"selactdir"},
  {UNSELACTFILE_WCP,"unselactfile"},
  {SELACTFILE_WCP,"selactfile"},
  {LVBG_WCP,"lvbg"},
  {STARTUP_WCP,"startup"},
  {BUTTON_WCP,"button"},
  {BUTTONS_WCP,"buttons"},
  {POSITION_WCP,"position"},
  {TITLE_WCP,"title"},
  {COMMANDS_WCP,"commands"},
  {SHORTKEYS_WCP,"shortkeys"},
  {PATHS_WCP,"paths"},
  {PATH_WCP,"path"},
  {FILETYPES_WCP,"filetypes"},
  {FILETYPE_WCP,"filetype"},
  {NORMAL_WCP,"normal"},
  {NOTYETCHECKED_WCP,"notyetchecked"},
  {UNKNOWN_WCP,"unknown"},
  {NOSELECT_WCP,"noselect"},
  {DIR_WCP,"dir"},
  {USEPATTERN_WCP,"usepattern"},
  {USECONTENT_WCP,"usecontent"},
  {PATTERN_WCP,"pattern"},
  {CONTENT_WCP,"content"},
  {FTCOMMANDS_WCP,"ftcommands"},
  {DND_WCP,"dnd"},
  {DC_WCP,"doubleclick"},
  {SHOW_WCP,"show"},
  {RAWSHOW_WCP,"rawshow"},
  {USER_WCP,"user"},
  {FLAGS_WCP,"flags"},
  {IGNOREDIRS_WCP,"ignoredirs"},
  {HOTKEYS_WCP,"hotkeys"},
  {HOTKEY_WCP,"hotkey"},
  {FONTS_WCP,"fonts"},
  {GLOBALFONT_WCP,"globalfont"},
  {BUTTONFONT_WCP,"buttonfont"},
  {LEFTFONT_WCP,"leftfont"},
  {RIGHTFONT_WCP,"rightfont"},
  {CLOCKBARSETS_WCP,"clockbarsets"},
  {MODUS_WCP,"modus"},
  {TIMESPACE_WCP,"timespace"},
  {TIME_WCP,"time"},
  {VERSION_WCP,"version"},
  {EXTERN_WCP,"extern"},
  {UPDATETIME_WCP,"updatetime"},
  {PROGRAM_WCP,"program"},
  {KEY_WCP,"key"},
  {DOUBLE_WCP,"double"},
  {MOD_WCP,"mod"},
  {CONTROL_WCP,"control"},
  {SHIFT_WCP,"shift"},
  {LOCK_WCP,"lock"},
  {MOD1_WCP,"mod1"},
  {MOD2_WCP,"mod2"},
  {MOD3_WCP,"mod3"},
  {MOD4_WCP,"mod4"},
  {MOD5_WCP,"mod5"},
  {DNDACTION_WCP,"dndaction"},
  {DCACTION_WCP,"doubleclickaction"},
  {SHOWACTION_WCP,"showaction"},
  {RSHOWACTION_WCP,"rawshowaction"},
  {USERACTION_WCP,"useraction"},
  {ROWUP_WCP,"rowup"},
  {ROWDOWN_WCP,"rowdown"},
  {CHANGEHIDDENFLAG_WCP,"changehiddenflag"},
  {COPYOP_WCP,"copyop"},
  {FIRSTROW_WCP,"firstrow"},
  {LASTROW_WCP,"lastrow"},
  {PAGEUP_WCP,"pageup"},
  {PAGEDOWN_WCP,"pagedown"},
  {SELECTOP_WCP,"selectop"},
  {SELECTALLOP_WCP,"selectallop"},
  {SELECTNONEOP_WCP,"selectnoneop"},
  {INVERTALLOP_WCP,"invertallop"},
  {PARENTDIROP_WCP,"parentdirop"},
  {ENTERDIROP_WCP,"enterdirop"},
  {CHANGELISTERSETOP_WCP,"changelistersetop"},
  {SWITCHLISTEROP_WCP,"switchlisterop"},
  {FILTERSELECTOP_WCP,"filterselectop"},
  {FILTERUNSELECTOP_WCP,"filterunselectop"},
  {PATHTOOTHERSIDEOP_WCP,"path2osideop"},
  {QUITOP_WCP,"quitop"},
  {DELETEOP_WCP,"deleteop"},
  {RELOADOP_WCP,"reloadop"},
  {MAKEDIROP_WCP,"makedirop"},
  {RENAMEOP_WCP,"renameop"},
  {DIRSIZEOP_WCP,"dirsizeop"},
  {SIMDDOP_WCP,"simddop"},
  {STARTPROGOP_WCP,"startprogop"},
  {SEARCHENTRYOP_WCP,"searchentryop"},
  {ENTERPATHOP_WCP,"enterpathop"},
  {SCROLLLISTEROP_WCP,"scrolllisterop"},
  {CREATESYMLINKOP_WCP,"createsymlinkop"},
  {CHANGESYMLINKOP_WCP,"changesymlinkop"},
  {CHMODOP_WCP,"chmodop"},
  {TOGGLELISTERMODEOP_WCP,"togglelistermodeop"},
  {SETSORTMODEOP_WCP,"setsortmodeop"},
  {SETFILTEROP_WCP,"setfilterop"},
  {SHORTKEYFROMLISTOP_WCP,"shortkeyfromlistop"},
  {CHOWNOP_WCP,"chownop"},
  {WORKERCONFIG_WCP,"workerconfig"},
  {USERSTYLE_WCP,"userstyle"},
  {DATESTRING_WCP,"datestring"},
  {TIMESTRING_WCP,"timestring"},
  {COLOR_WCP,"color"},
  {PATTERNIGNORECASE_WCP,"patternignorecase"},
  {PATTERNUSEREGEXP_WCP,"patternuseregexp"},
  {PATTERNUSEFULLNAME_WCP,"patternusefullname"},
  {COM_WCP,"com"},
  {SEPARATEEACHENTRY_WCP,"separateeachentry"},
  {RECURSIVE_WCP,"recursive"},
  {START_WCP,"start"},
  {TERMINALWAIT_WCP,"terminalwait"},
  {SHOWOUTPUT_WCP,"showoutput"},
  {VIEWSTR_WCP,"viewstr"},
  {INBACKGROUND_WCP,"inbackground"},
  {TAKEDIRS_WCP,"takedirs"},
  {ACTIONNUMBER_WCP,"actionnumber"},
  {ROWUP_WCP,"rowup"},
  {HIDDENFILES_WCP,"hiddenfiles"},
  {HIDE_WCP,"hide"},
  {TOGGLE_WCP,"toggle"},
  {FOLLOWSYMLINKS_WCP,"followsymlinks"},
  {MOVE_WCP,"move"},
  {RENAME_WCP,"rename"},
  {SAMEDIR_WCP,"samedir"},
  {REQUESTDEST_WCP,"requestdest"},
  {REQUESTFLAGS_WCP,"requestflags"},
  {OVERWRITE_WCP,"overwrite"},
  {ALWAYS_WCP,"always"},
  {NEVER_WCP,"never"},
  {COPYMODE_WCP,"copymode"},
  {FAST_WCP,"fast"},
  {PRESERVEATTR_WCP,"preserveattr"},
  {MODE_WCP,"mode"},
  {ACTIVE_WCP,"active"},
  {ACTIVE2OTHER_WCP,"active2other"},
  {SPECIAL_WCP,"special"},
  {REQUEST_WCP,"request"},
  {CURRENT_WCP,"current"},
  {OTHER_WCP,"other"},
  {FILTER_WCP,"filter"},
  {QUICK_WCP,"quick"},
  {ALSOACTIVE_WCP,"alsoactive"},
  {RESETDIRSIZES_WCP,"resetdirsizes"},
  {KEEPFILETYPES_WCP,"keepfiletypes"},
  {RELATIVE_WCP,"relative"},
  {ONFILES_WCP,"onfiles"},
  {ONDIRS_WCP,"ondirs"},
  {SORTBY_WCP,"sortby"},
  {SORTFLAG_WCP,"sortflag"},
  {REVERSE_WCP,"reverse"},
  {DIRLAST_WCP,"dirlast"},
  {DIRMIXED_WCP,"dirmixed"},
  {EXCLUDE_WCP,"exclude"},
  {INCLUDE_WCP,"include"},
  {UNSET_WCP,"unset"},
  {UNSETALL_WCP,"unsetall"},
  {SCRIPTOP_WCP,"scriptop"},
  {NOP_WCP,"nop"},
  {PUSH_WCP,"push"},
  {LABEL_WCP,"label"},
  {IF_WCP,"if"},
  {END_WCP,"end"},
  {POP_WCP,"pop"},
  {SETTINGS_WCP,"settings"},
  {WINDOW_WCP,"window"},
  {GOTO_WCP,"goto"},
  {PUSHUSEOUTPUT_WCP,"pushuseoutput"},
  {DODEBUG_WCP,"dodebug"},
  {WPURECURSIVE_WCP,"wpurecursive"},
  {WPUTAKEDIRS_WCP,"wputakedirs"},
  {STACKNR_WCP,"stacknr"},
  {PUSHSTRING_WCP,"pushstring"},
  {IFTEST_WCP,"iftest"},
  {IFLABEL_WCP,"iflabel"},
  {WINTYPE_WCP,"wintype"},
  {OPEN_WCP,"open"},
  {CLOSE_WCP,"close"},
  {LEAVE_WCP,"leave"},
  {CHANGEPROGRESS_WCP,"changeprogress"},
  {CHANGETEXT_WCP,"changetext"},
  {PROGRESSUSEOUTPUT_WCP,"progressuseoutput"},
  {WINTEXTUSEOUTPUT_WCP,"wintextuseoutput"},
  {PROGRESS_WCP,"progress"},
  {WINTEXT_WCP,"wintext"},
  {SHOWDIRCACHEOP_WCP,"showdircacheop"},
  {ACTIVESIDE_WCP,"activeside"},
  {SHOWFREESPACE_WCP,"showfreespace"},
  {ACTIVEMODE_WCP,"activemode"},
  { INODE_WCP, "inode" },
  { NLINK_WCP, "nlink" },
  { BLOCKS_WCP, "blocks" },
  { SHOWHEADER_WCP, "showheader" },
  { LVHEADER_WCP, "lvheader" },
  { IGNORECASE_WCP, "ignorecase" },
  { LISTVIEWS_WCP, "listviews" },
  { BLL_WCP, "bll" },
  { LBL_WCP, "lbl" },
  { LLB_WCP, "llb" },
  { BL_WCP, "bl" },
  { LB_WCP, "lb" },
  { LAYOUT_WCP, "layout" },
  { BUTTONSVERT_WCP, "buttonsvertical" },
  { LISTVIEWSVERT_WCP, "listviewsvertical" },
  { EXTCOND_WCP, "extcond" },
  { USEEXTCOND_WCP, "useextcond" }
};

ArrayList *tokenlist_sorted = NULL;

int tokenlist_sortfunction( void *p1, void *p2 )
{
  if ( ( p1 == NULL ) || ( p2 == NULL ) ) return 0;
  return strcasecmp( ((struct mytoken*)p1)->str,
                     ((struct mytoken*)p2)->str );
}

void cleanUpTokens()
{
  // the list contains just pointers to the static array so
  // delete of list is enough
  delete tokenlist_sorted;
  tokenlist_sorted = NULL;
}

int findToken( const char *str)
{
  int s, i, left, right, middle, erg;
  struct mytoken *t1;
  
  if ( tokenlist_sorted == NULL ) {
    // init sorted token list for binary search
    tokenlist_sorted = new ArrayList();
    s = sizeof( tokenlist ) / sizeof( tokenlist[0] );
    for ( i = 0; i < s; i++ ) {
      tokenlist_sorted->addElement( &( tokenlist[i] ) );
    }
    tokenlist_sorted->sort( tokenlist_sortfunction );
  }
  
  s = tokenlist_sorted->size();
  left = 0;
  right = s - 1;
  do {
    middle = ( left + right ) / 2;
    t1 = (struct mytoken*)tokenlist_sorted->getElementAt( middle );
    if ( t1 == NULL ) return ERROR;
    erg = strcasecmp( str, t1->str );
    if ( erg == 0 ) return t1->token;
    else if ( erg < 0 ) {
      right = middle - 1;
    } else {
      left = middle + 1;
    }
  } while ( left <= right );
  return ERROR;
}
